==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridRowEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditStartedEventArgsDescription } from "./GridRowEditStartedEventArgsDescription";
/**
 * @hidden
 */
export let GridRowEditStartedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridRowEditStartedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridRowEditStartedEventArgsDescriptionMetadata.a == null) {
                GridRowEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridRowEditStartedEventArgsDescriptionMetadata.c(GridRowEditStartedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridRowEditStartedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridRowEditStartedEventArgsDescriptionMetadata.b(a);
            a.ac("GridRowEditStartedEventArgs", () => new GridRowEditStartedEventArgsDescription());
            a.ab("GridRowEditStartedEventArgs", GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
    }
    GridRowEditStartedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridRowEditStartedEventArgsDescriptionMetadata, 'GridRowEditStartedEventArgsDescriptionMetadata');
    GridRowEditStartedEventArgsDescriptionMetadata.a = null;
    return GridRowEditStartedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GridRowEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditStartedEventArgsDescription } from "./GridRowEditStartedEventArgsDescription";
/**
 * @hidden
 */
export let GridRowEditStartedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridRowEditStartedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridRowEditStartedEventArgsDescriptionMetadata.a == null) {
                GridRowEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridRowEditStartedEventArgsDescriptionMetadata.c(GridRowEditStartedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridRowEditStartedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridRowEditStartedEventArgsDescriptionMetadata.b(a);
            a.ae("GridRowEditStartedEventArgs", () => new GridRowEditStartedEventArgsDescription());
            a.ad("GridRowEditStartedEventArgs", GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
    }
    GridRowEditStartedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridRowEditStartedEventArgsDescriptionMetadata, 'GridRowEditStartedEventArgsDescriptionMetadata');
    GridRowEditStartedEventArgsDescriptionMetadata.a = null;
    return GridRowEditStartedEventArgsDescriptionMetadata;
})();
